@@ -2,12 +2,12 @@ import warnings
 
 from ocdsextensionregistry import ProfileBuilder
 from ocdsmerge import Merger
-from ocdsmerge.util import get_release_schema_url, get_tags
+from ocdsmerge.util import get_release_schema_url
 
 from ocdskit.exceptions import MissingRecordsWarning, MissingReleasesWarning
 from ocdskit.packager import Packager
 from ocdskit.util import (_empty_record_package, _empty_release_package, _remove_empty_optional_metadata,
-                          _resolve_metadata, _update_package_metadata)
+                          _resolve_metadata, _update_package_metadata, get_ocds_patch_tag)
 
 DEFAULT_VERSION = '1.1'  # fields might be deprecated
 
@@ -153,18 +153,19 @@ def merge(data, uri='', publisher=None, published_date='', version=DEFAULT_VERSI
         if the calling code exhausts the generator before ``merge`` returns)
     :raises InconsistentVersionError: if the versions are inconsistent across packages to merge
     :raises MissingOcidKeyError: if the release is missing an ``ocid`` field
+    :raises UnknownVersionError: if the OCDS version is not recognized
     """
     with Packager() as packager:
         packager.add(data)
 
         if not schema and packager.version:
-            prefix = packager.version.replace('.', '__') + '__'
-            tag = next(tag for tag in reversed(get_tags()) if tag.startswith(prefix))
-            schema = get_release_schema_url(tag)
-
+            tag = get_ocds_patch_tag(packager.version)
             if packager.package['extensions']:
+                # `extensions` is an insertion-ordered dict at this point.
                 builder = ProfileBuilder(tag, list(packager.package['extensions']))
                 schema = builder.patched_release_schema()
+            else:
+                schema = get_release_schema_url(tag)
 
         merger = Merger(schema)
 
